@@ -2,23 +2,16 @@
 #define FOURVECTOR_H
 
 #include <iostream>
-struct FourVector
-{
-
+struct FourVector {
     int ix, iy, iz, sublattice;
 
-    FourVector()
-        : ix(0), iy(0), iz(0), sublattice(0)
-    {
+    FourVector() : ix(0), iy(0), iz(0), sublattice(0) {
     }
     FourVector(int ix, int iy, int iz, int sublattice)
-        : ix(ix), iy(iy), iz(iz), sublattice(sublattice)
-    {
+        : ix(ix), iy(iy), iz(iz), sublattice(sublattice) {
     }
 
-    FourVector(const FourVector &fv)
-        : ix(fv.ix), iy(fv.iy), iz(fv.iz), sublattice(fv.sublattice)
-    {
+    FourVector(const FourVector &fv) : ix(fv.ix), iy(fv.iy), iz(fv.iz), sublattice(fv.sublattice) {
 #ifdef PRINT_DEBUG_EXTRA
         std::cout << "Copied 4-vector!" << std::endl;
 #endif
